import { create } from 'd3-selection';
import { scaleLinear } from 'd3-scale';
import { extent } from 'd3-array';
import { axisLeft, axisBottom } from 'd3-axis';

export const ScatterPlot = ({
  data,
  xAccessor,
  yAccessor,
  radius,
  margin,
  width,
  height,
}) => {
  const svg = create('svg')
    .attr('width', width)
    .attr('height', height);

  const xScale = scaleLinear()
    .domain(extent(data, xAccessor))
    .range([margin.left, width - margin.right]);

  const yScale = scaleLinear()
    .domain(extent(data, yAccessor))
    .range([height - margin.bottom, margin.top]);

  svg
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('cy', (d) => yScale(yAccessor(d)))
    .attr('cx', (d) => xScale(xAccessor(d)))
    .attr('r', radius);

  svg
    .append('g')
    .attr('transform', `translate(${margin.left}, 0)`)
    .call(axisLeft(yScale));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`
    )
    .call(axisBottom(xScale));

  return svg.node();
};
